# index-generator

Yet another python index generator

[![Travis](https://img.shields.io/travis/BruceZhang1993/index-generator.svg?style=for-the-badge)](https://travis-ci.org/BruceZhang1993/index-generator)
[![GitHub top language](https://img.shields.io/github/languages/top/BruceZhang1993/index-generator.svg?style=for-the-badge)](https://github.com/BruceZhang1993/index-generator)
[![Requires.io](https://img.shields.io/requires/github/BruceZhang1993/index-generator.svg?style=for-the-badge)](https://requires.io/github/BruceZhang1993/index-generator/requirements/?branch=master)
[![GitHub](https://img.shields.io/github/license/BruceZhang1993/index-generator.svg?style=for-the-badge)](https://github.com/BruceZhang1993/index-generator/blob/master/LICENSE)
[![Codacy grade](https://img.shields.io/codacy/grade/3aef89bd80514ba0a2e353aefac47ebe.svg?style=for-the-badge)](https://app.codacy.com/project/BruceZhang1993/index-generator/dashboard)
[![Codacy coverage](https://img.shields.io/codacy/coverage/3aef89bd80514ba0a2e353aefac47ebe.svg?style=for-the-badge)](https://app.codacy.com/project/BruceZhang1993/index-generator/dashboard)

## Install

### Pypi

[![PyPI](https://img.shields.io/pypi/v/index-generator.svg?style=for-the-badge)](https://pypi.org/project/index-generator)

```bash
pip install index-generator
```

### GitHub release

[![GitHub release](https://img.shields.io/github/release/BruceZhang1993/index-generator.svg?style=for-the-badge)](https://github.com/BruceZhang1993/index-generator/releases)

You can just download wheel(.whl) file, and install using `pip install`.

### Distributions

#### Arch Linux

```bash
# Coming soon
```

#### Other Distribution

### GitHub master branch

```bash
git clone https://github.com/BruceZhang1993/index-generator.git
cd index-generator
sudo python setup.py install
# OR
sudo pip install .
```

## Usage

See [Wiki Page](https://github.com/BruceZhang1993/index-generator/wiki)

## License

[MIT](https://github.com/BruceZhang1993/index-generator/blob/master/LICENSE)

## Contributors

    Sorting by alphabet order. 

- Bruce Zhang ([BruceZhang1993](https://github.com/BruceZhang1993))
- Edward P ([edward-p](https://github.com/edward-p))

[More...](https://github.com/BruceZhang1993/index-generator/graphs/contributors)
